@@ -20,7 +20,7 @@ function return_string_txtarea($string, $filename) {
 		</SCRIPT>';
 
 	$feedback .= '<FONT color="#FF0000">'.$txt['setup_cant_save'];
-	$feedback .= ' <B>'.$filename.'</B> '.$txt['setup_cant_save2'].'</FONT>';
+	$feedback .= ' <B>'.$filename.'</B> '.$txt['setup_cant_save_2'].'</FONT>';
 	$feedback .= '<FORM name="feedback">';
 	$feedback .= '<TEXTAREA cols="50" rows="10" name="conf" class="trous">';
 	$feedback .= $string;
@@ -785,6 +785,7 @@ function generate_config($confDB_new = '', $conf_new = '', $install = 0) {
 	
 	$confDBCookie 		= isset($HTTP_COOKIE_VARS['ConfDBCookie']) ? $HTTP_COOKIE_VARS['ConfDBCookie'] : '';
 	$old_config_name 	= isset($confDB[$confDBCookie]['name']) ? $confDB[$confDBCookie]['name'] : '';
+	$output				= '';
 	
 	### Modifying only the new settings
 	$confDB_new 		= ($confDB_new == '') ? $confDB : $confDB_new;
@@ -1137,4 +1138,4 @@ function create_cfg() {
 
     return $output;
 }
-?>
\ No newline at end of file
+?>
